import "./endQuizModal.css";
import { ModalButton } from "../../../components/quiz/modalButton/modalButton.tsx";
import { useNavigate } from "react-router-dom";
import { MultiplayerQuizInformations } from "../../../models/QuizInformations.ts";
import { UserEndQuiz } from "../../../models/UserEndQuiz.ts";
import { List } from "../../../components/list/list.tsx";
import { useEffect, useState } from "react";
import ListModel from "../../../models/ListModel.ts";

interface Props {
    isOpen: boolean;
    onClose: () => void;
    users: UserEndQuiz[];
    questionCount: number;
    score: number;
}

export const EndQuizModalMulti = ({ isOpen, onClose, users, questionCount, score }: Props) => {
    const [liste, setListe] = useState<ListModel[]>([]);
    if (!isOpen) return null;
    const navigate = useNavigate();

    const handleBackToMenu = () => {
        navigate("/multiplayer");
    };

    // const renderUser = ({ item, index }: { item: UserEndQuiz; index: number }) => (
    //     <div className={index === 0 ? "first-place score-item" : "score-item"} key={index}>
    //         <img
    //             src={require("../../../assets/ProfilBaseImage.png")} // Replace with actual profile picture if available
    //             className="avatar"
    //         />
    //         <div className="infoContainer">
    //             <p className={index === 0 ? "username username-firstplace" : "username"}>
    //                 {item.username.toUpperCase()}
    //             </p>
    //             <p className="score">
    //                 {10 + index}/{questionCount} {/* Adjust score logic as needed */}
    //             </p>
    //         </div>
    //     </div>
    // );

    useEffect(() => {
        formatliste(users);
    }, []);


    const formatliste = (users: UserEndQuiz[]) => {
        const temp: ListModel[] = users.map((user, index) => ({
            id: user.username,
            title: user.username,
            content: `${user.score}/${questionCount}`,
        }));
        setListe(temp);
    }

    const toIgnore = (index: string) => {
    }

    return (
        <div className="end-quiz-modal-overlay">
            <div className="end-quiz-modal-content" onClick={(e) => e.stopPropagation()}>
                <div>
                    <p className="end-quiz-modal-button-title">CONGRATS !</p>
                </div>
                <div className="end-quiz-modal-button-text-container">
                    <p className="end-quiz-modal-button-text">YOU FINISH THE TEST WITH A</p>
                    <p className="end-quiz-modal-button-text">
                        SCORE OF {score}/{questionCount} !
                    </p>
                </div>
                <div className="end-quiz-modal-scores-container">
                    <div className="end-quiz-modal-scores">
                        <img src="/stars.png" alt="stars picture" className="stars-image" />
                        {
                            users.map((user, index) => (
                                index <= 2 ? (
                                    <div key={index} className="score-item">
                                        <img
                                            src="/ProfilBaseImage.png"
                                            className="avatar"
                                        />
                                        <p>{user.username}</p>
                                        <p>{user.score}/{questionCount}</p>
                                    </div>
                                ) : null
                            ))
                        }
                        <img src="/stars.png" alt="stars picture" className="stars-image-reverse" />
                    </div>
                    <div className="end-quiz-modal-scores">
                        <div className="player-list-container">
                            {liste.map((item) => (
                                <div className="player-list-item" key={item.id.toString()}>
                                    <div className="player-list-info">{item.title}</div>
                                    <div className="player-list-info">{item.content}</div>
                                </div>
                            ))}
                        </div>
                    </div>
                </div>

                <div className="end-quiz-modal-button-container">
                    {/*<ModalButton text="RESTART" onClick={onClose} isLeftButton={true} isDisabled={false}/>*/}
                    <ModalButton
                        text="BACK TO MENU"
                        onClick={handleBackToMenu}
                        isLeftButton={false}
                        isDisabled={false}
                    />
                </div>
            </div>
        </div>
    );
};
